@@ -19,12 +19,8 @@ from pkg_resources import resource_filename
 from unihandecode.unidecoder import Unidecoder
 
 class Vndecoder(Unidecoder):
-
     codepoints = {}
 
     def __init__(self):
-        unicodepoints_pkl = open(resource_filename(__name__, 'unicodepoints.pickle'), 'rb')
-        (self.codepoints, dlen) = load(unicodepoints_pkl)
-        dict_pkl = open(resource_filename(__name__, 'vncodepoints.pickle'), 'rb')
-        (dic, dlen) = load(dict_pkl)
-        self.codepoints.update(dic)
+        self._load_codepoints('vn')
+
